@@ -221,8 +221,16 @@ class AnalysisData:
                 self.available_tags[k].add(v)
 
     def __call__(
-        self, *, version=None, name=None, return_pfns=True, check_data=True, **tags
+        self,
+        *,
+        version=None,
+        name=None,
+        return_pfns=True,
+        check_data=True,
+        showmax=10,
+        **tags,
     ):
+        # pylint: disable-msg=too-many-locals
         """Main method that returns the dataset info.
         The normal behaviour is to return the PFNs for the samples but setting
         return_pfns to false returns the SampleCollection"""
@@ -274,15 +282,21 @@ class AnalysisData:
             if check_data:
                 errors = sample_check(samples, effective_tags)
                 if len(errors) > 0:
-                    error_txt = f"{len(errors)} problem(s) found"
+                    error_txt = f"{len(errors)} problem(s) found\n"
                     for etags, ecount in errors:
-                        error_txt += f"\n{str(etags)}: {ecount} samples"
+                        if etags:
+                            error_txt += f"{str(etags)}: "
+                        error_txt += f"{ecount} samples for the same configuration found, this is ambiguous:"
                         if ecount > 0:
-                            error_txt += " e.g. (3 samples printed)"
+                            error_txt += (
+                                f"(only the first {showmax} samples printed)"
+                                if (ecount > showmax)
+                                else ""
+                            )
                             match_list = [
                                 str(m)
                                 for m in itertools.islice(
-                                    samples.filter(**etags).itertags(), 0, 3
+                                    samples.filter(**etags).itertags(), 0, showmax
                                 )
                             ]
                             error_txt += "".join(
@@ -305,7 +319,10 @@ class AnalysisData:
         return f"<AnalysisData: WG={self.analysis}, analysis={self.working_group}, n_samples={len(self.samples)}>"
 
     def summary(self, tags: list = None) -> dict:
-        summary = {}
+        """prepares a summary of the Analysis Production info"""
+
+        # Deal with the tags first
+        tag_summary = {}
         if tags:
             for tag in tags:
                 if tag in self.available_tags:
@@ -316,11 +333,22 @@ class AnalysisData:
                             f"Could not sort the values for tag ({tag}). Please check that the values are sensible.\n"
                         ) from exc
                     values = list(self.available_tags[tag])
-                    summary[tag] = values
+                    tag_summary[tag] = values
                 else:
                     raise ValueError(
                         f"Requested tag ({tag}) not valid for the given production (wg: {self.working_group}, analysis: {self.analysis})!"
                     )
         else:
-            summary = self.available_tags
+            tag_summary = dict(self.available_tags)
+
+        summary = {}
+        summary["tags"] = tag_summary
+
+        # If we specify the tags to be list, we assume the general information should not be printed
+        if not tags:
+            summary["analysis"] = self.analysis
+            summary["working_group"] = self.working_group
+            summary["Number_of_files"] = self.samples.file_count()
+            summary["Bytecount"] = self.samples.byte_count()
+
         return summary
