@@ -175,7 +175,8 @@ class SampleCollection:
     def __repr__(self):
         return "\n".join(
             [
-                f"{s['name']} {s['version']} | " + str(self._sampleTags(s))
+                f"{s['name']} {s['version']} files:{len(s['lfns'])} bytes:{s['total_bytes']/(1024*1024*1024):.1f} GiB | "
+                + str(self._sampleTags(s))
                 for s in self.info
             ]
         )
@@ -237,10 +238,25 @@ class SampleCollection:
         """Collects the PFNs"""
         pfns = []
         for sample in self.info:
+            # this is a map called 'lfns', in which we have the pfns for each lfn
             for pfnlist in sample["lfns"].values():
                 pfns.append(auth(pfnlist[0]))
         return pfns
 
+    def byte_count(self):
+        """Collects the number of files from all the samples"""
+        count = 0
+        for sample in self.info:
+            count += sample["total_bytes"]
+        return count
+
+    def file_count(self):
+        """Collects total bytecount"""
+        count = 0
+        for sample in self.info:
+            count += len(sample["lfns"].keys())
+        return count
+
     def __or__(self, samples):
         info = self.info + samples.info
         tags = {**(self.tags), **(samples.tags)}
