@@ -64,13 +64,19 @@ def cmd_login():
         _, token_file = tempfile.mkstemp(prefix="apd-", suffix=".json")
         os.environ["LBAP_TOKENS_FILE"] = token_file
         print(f"export LBAP_TOKENS_FILE={token_file}")
-    r = requests.get(
-        "https://lbap.app.cern.ch/user/",
-        **get_auth_headers(),
-        timeout=10,
-    )
-    r.raise_for_status()
-    console.print(f"Login successful as {r.json()['username']}")
+    try:
+        r = requests.get(
+            "https://lbap.app.cern.ch/user/",
+            **get_auth_headers(),
+            timeout=10,
+        )
+        r.raise_for_status()
+        console.print(f"Login successful as {r.json()['username']}")
+    except Exception:  # pylint: disable=broad-except
+        # Ensure GitLab CI jobs exit if something goes wrong
+        if "CI_JOB_JWT_V2" in os.environ:
+            print("exit 42")
+        raise
 
 
 @click.command()
