@@ -85,5 +85,5 @@ def test_sample_check_load_dataset_error(apinfo_multipleversions):
 def test_summary(apinfo_multipleversions):
     datasets = AnalysisData("SL", "RDs", metadata_cache=apinfo_multipleversions)
     tagname = "datatype"
-    dt = set(datasets.summary([tagname])[tagname])
+    dt = set(datasets.summary([tagname])["tags"][tagname])
     assert dt == set(["2011", "2018", "2016", "2017", "2012"])
